@@ -1,6 +1,7 @@
 from requests import Response
 from .LoginStepHandler import LoginStepHandler
 from .OnlineChecker import OnlineChecker
+from .Logger import logger
 
 
 class LoginFinalizeHandler(LoginStepHandler):
@@ -8,5 +9,5 @@ class LoginFinalizeHandler(LoginStepHandler):
         del accumulated["login_barcode"]
         del accumulated["login_success_url"]
         resp = OnlineChecker.check_online(accumulated, self.session)
-        print(resp)
+        logger.info(resp.content)
         return accumulated, resp
